@@ -5,7 +5,7 @@ use Exporter;
 use YAML::Syck ();
 
 BEGIN {
-    $VERSION    = '0.33';
+    $VERSION    = '0.36';
     @EXPORT_OK  = qw( Load Dump LoadFile DumpFile );
     @ISA        = 'Exporter';
     *Load       = \&YAML::Syck::LoadJSON;
@@ -18,10 +18,9 @@ sub DumpFile {
         print {$file} YAML::Syck::DumpJSON($_[0]);
     }
     else {
-        local *FH;
-        open FH, "> $file" or die "Cannot write to $file: $!";
-        print FH YAML::Syck::DumpJSON($_[0]);
-        close FH;
+        open(my $fh, '>',  $file) or die "Cannot write to $file: $!";
+        print {$fh} YAML::Syck::DumpJSON($_[0]);
+        close $fh;
     }
 }
 
@@ -29,12 +28,17 @@ sub DumpFile {
 sub LoadFile {
     my $file = shift;
     if ( YAML::Syck::_is_openhandle($file) ) {
+        if(-z $file) {
+	    die("Cannot load an empty file");
+        }
         YAML::Syck::LoadJSON(do { local $/; <$file> });
     }
     else {
-        local *FH;
-        open FH, "< $file" or die "Cannot read from $file: $!";
-        YAML::Syck::LoadJSON(do { local $/; <FH> });
+        if(!-e $file || -z $file) {
+	    die("'$file' is non-existant or empty");
+	}
+        open(my $fh, '<', $file) or die "Cannot read from $file: $!";
+        YAML::Syck::LoadJSON(do { local $/; <$fh> });
     }
 }
 
